@@ -51,12 +51,10 @@ my $configure_gnusocial=sub {
    my $region=$_[4]||'';
    my $verified_email=$_[5]||'';
    my $permanent_ip=$_[6]||'';
+   my $site_name=$_[7]||'';
    $permanent_ip='' if $permanent_ip=~/Stay|Reason/;
-   if ($permanent_ip=~/Elastic/) {
-      my $c="aws ec2 allocate-address --domain vpc";
-      my ($hash,$output,$error)=run_aws_cmd($c);
-      $hash||={};
-      $permanent_ip=$hash->{PublicIp}; 
+   if ($permanent_ip=~/Elastic/ && exists $main::aws->{permanent_ip}) {
+      $permanent_ip=$main::aws->{permanent_ip}; 
    }
    my $handle=$main::aws->{$server_type}->[$cnt]->[1];
    my $local=connect_shell();
@@ -725,7 +723,7 @@ END
    my $response = $Browser->post(
       "https://$public_ip/install.php",
       [
-         'sitename' => 'FullAuto',
+         'sitename' => $site_name,
          'fancy' => 'enable',
          'ssl' => 'always',
          'host' => 'localhost',
@@ -805,11 +803,13 @@ END
       "${sudo}echo -e \"$access\" >> /etc/mail/access");
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}chmod -v 644 /etc/mail/access");
+   my $email_domain=$verified_email;
+   $email_domain=~s/^.*\@(.*)$/$1/;
    $ad="define(`SMART_HOST%SQ%, `$smtp_server%SQ%)dnl%NL%".
        "define(`RELAY_MAILER_ARGS%SQ%, `TCP \$h 25%SQ%)dnl%NL%".
        "define(`confAUTH_MECHANISMS%SQ%, `LOGIN PLAIN%SQ%)dnl%NL%".
        "FEATURE(`authinfo%SQ%, `hash -o /etc/mail/authinfo.db%SQ%)dnl%NL%".
-       "MASQUERADE_AS(`fullauto.com%SQ%)dnl%NL%".
+       "MASQUERADE_AS(`$email_domain%SQ%)dnl%NL%".
        "FEATURE(masquerade_envelope)dnl%NL%".
        "FEATURE(masquerade_entire_domain)dnl";
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i ".
@@ -835,13 +835,12 @@ END
       '/var/www/gnusocial/plugins','__display__');
    ($stdout,$stderr)=$handle->cmd("${sudo}rm -rfv ".
       'statusnet-questioncaptcha-plugin','__display__');
-   ($stdout,$stderr)=$handle->cmd("${sudo}php ".
-      '/var/www/gnusocial/plugins/QuestionCaptcha/scripts/'.
-      'generate-codes.php -c 10 -l 10','__display__');
-print "STDOUT=$stdout<== and ERROR=$stderr\n";
-   $stdout=~s/^.*(addPlugin.*)$/$1/s;
+   #($stdout,$stderr)=$handle->cmd("${sudo}php ".
+   #   '/var/www/gnusocial/plugins/QuestionCaptcha/scripts/'.
+   #   'generate-codes.php -c 10 -l 10','__display__');
+   #$stdout=~s/^.*(addPlugin.*)$/$1/s;
    my $config_email=<<END;
-\\x24config['mail']['domain'] = 'fullauto.com';
+\\x24config['mail']['domain'] = \'$email_domain\';
 \\x24config['mail']['notifyfrom'] = \'$verified_email\';
 \\x24config['mail']['backend'] = 'sendmail';
 \\x24config['mail']['params'] = array(
@@ -851,9 +850,10 @@ print "STDOUT=$stdout<== and ERROR=$stderr\n";
 'username' => \'$access_id\',
 'password' => \'$smtppass\'
 );
-addPlugin('EmailRegistration');
-$stdout
 END
+#addPlugin('EmailRegistration');
+#$stdout
+#END
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}echo -e \"$config_email\" >> /var/www/gnusocial/config.php");
    ($stdout,$stderr)=$handle->cmd(
@@ -906,6 +906,10 @@ my $standup_gnusocial=sub {
    }
    my $gnusocial="]T[{select_gnusocial_setup}";
    my $permanent_ip="]T[{permanent_ip}";
+   my $site_name="]I[{'gnusocial_enter_site_name',1}";
+   #if (-1<index $site_name, ']T[') {
+   #   $site_name="]I[{'gnusocial_enter_domain_name',1}"; 
+   #}
    my $i=$main::aws->{fullauto}->{ImageId}||'';
    my $s=$main::aws->{fullauto}->
          {NetworkInterfaces}->[0]->{SubnetId}||'';
@@ -955,13 +959,13 @@ my $standup_gnusocial=sub {
       if ($#{$main::aws->{'GNU.io/Social'}}==0) {
          launch_server('GNU.io/Social',$cnt,$gnusocial,'',$c,
          $configure_gnusocial,'',$region,$verified_email,
-         $permanent_ip);
+         $permanent_ip,$site_name);
       } else {
          my $num=$#{$main::aws->{'GNU.io/Social'}}-1;
          foreach my $num (0..$num) {
             launch_server('GNU.io/Social',$cnt++,$gnusocial,'',$c,
             $configure_gnusocial,'',$region,$verified_email,
-            $permanent_ip);
+            $permanent_ip,$site_name);
          }
       }
    }
@@ -1110,17 +1114,18 @@ END
          Item_1 => {
 
             Text => 'Use Elastic (Permanent) IP Address',
-            Result => $gnusocial_setup_summary,
+            Result => 
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_site_name,
 
          },
          Item_2 => {
 
             Text => 'Stay with Temporary Public IP Address',
-            Result => $gnusocial_setup_summary,
+            Result =>
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_site_name,
 
          },
          Scroll => 2,
-         Result => $gnusocial_setup_summary,
          Banner => $permanent_ip_banner,
 
       };
@@ -1170,7 +1175,8 @@ END
 
                Text => "Use Elastic (Permanent) IP Address ]C[",
                Convey => \@available,
-               Result => $gnusocial_setup_summary,
+               Result =>
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_site_name,
 
             },
             Item_2 => {
@@ -1178,17 +1184,18 @@ END
                Text => "Stay with Temporary Public IP Address &\n".
                        "                 ]C[ (to avoid cost)",
                Convey => \@available_remove,
-               Result => $gnusocial_setup_summary,
+               Result =>
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_site_name,
 
             },
             Item_3 => {
 
                Text => 'Stay with Temporary Public IP Address',
-               Result => $gnusocial_setup_summary,
+               Result =>
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_site_name,
 
             },
             Scroll => 3,
-            Result => $gnusocial_setup_summary,
             Banner => $use_elastic_banner,
 
          };
@@ -1215,17 +1222,18 @@ END
             Item_1 => {
 
                Text => 'Allocate Additional Elastic (Permanent) IP Address',
-               Result => $gnusocial_setup_summary,
+               Result =>
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_site_name,
 
             },
             Item_2 => {
 
                Text => 'Stay with Temporary Public IP Address',
-               Result => $gnusocial_setup_summary,
+               Result =>
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_site_name,
 
             },
             Scroll => 2,
-            Result => $gnusocial_setup_summary,
             Banner => $new_elastic_banner,
 
          };
@@ -1369,14 +1377,15 @@ END
 
             Text => "Enter and verify a different address\n\n",
             Result =>
-      $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_email_address->(),
+ $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_email_address->(),
 
          },
          Item_2 => {
 
             Text => "]C[",
             Convey => \@identities,
-            Result => $Net::FullAuto::ISets::Amazon::GNUSocial_is::check_elastic_ip,
+            Result =>
+               $Net::FullAuto::ISets::Amazon::GNUSocial_is::check_elastic_ip,
 
          },
          Scroll => 2,
@@ -1384,11 +1393,156 @@ END
       };
       return $pick_email;
    } else {
-      $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_email_address->();
+ $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_email_address->();
    }
 
 };
 
+our $gnusocial_enter_site_name=sub {
+
+   my $gnusocial_site_banner=<<'END';
+
+    ___     _             ___ _ _         _  _
+   | __|_ _| |_ ___ _ _  / __(_) |_ ___  | \| |__ _ _ __  ___
+   | _|| ' \  _/ -_) '_| \__ \ |  _/ -_) | .` / _` | '  \/ -_)
+   |___|_||_\__\___|_|   |___/_|\__\___| |_|\_\__,_|_|_|_\___|
+
+   The Site Name will appear within GNU Social as the name of your
+   GNU Social site. It may or may not be the same as a Domain Name
+   that you might setup or associate with your site. Setting up a
+   Domain Name for your site is outside the scope of this installer.
+END
+   $gnusocial_site_banner.=<<END;
+
+   Input box with === border is highlighted (active) input box.
+   Use [TAB] key to switch focus between input boxes.
+   Use [DEL] key to clear entire entry in highlighted input box.
+   Use [Backspace] to backspace in highlighted input box.
+
+   Type or Copy & Paste the Site Name for GNU Social here:
+
+
+   Site Name
+                    ]I[{1,'',50}
+
+END
+
+   my $gnusocial_enter_site_name={
+
+      Name => 'gnusocial_enter_site_name',
+      Input => 1,
+      #Result => $gnusocial_validate_domain,
+      Result => $gnusocial_setup_summary,
+      Banner => $gnusocial_site_banner,
+
+   };
+   return $gnusocial_enter_site_name;
+
+};
+
+our $gnusocial_validate_domain=sub {
+
+   package gnusocial_validate_domain;
+   my $domain="]I[{'gnusocial_enter_domain_name',1}";
+print "DOMAIN=$domain\n";<STDIN>;
+   my $c="aws ec2 allocate-address --domain vpc";
+   my ($hash,$output,$error)=
+         &Net::FullAuto::Cloud::fa_amazon::run_aws_cmd($c);
+   $hash||={};
+   $main::aws->{permanent_ip}=$hash->{PublicIp};
+
+   my $confirm='';
+   unless ($domain eq $confirm) {
+      STDOUT->autoflush(1);
+      print "\n   ERROR: Email Addresses do not match!";sleep 5;
+      STDOUT->autoflush(0);
+      return '<';
+   } elsif ($domain=~/^\s*$/) {
+      STDOUT->autoflush(1);
+      print "\n   ERROR: You failed to enter an Email Address!";sleep 5;
+      STDOUT->autoflush(0);
+      return '<';
+   } elsif ($domain!~/\@/) {
+      STDOUT->autoflush(1);
+      print "\n   ERROR: Email Address must contain \'\@\' character!";sleep 5;
+      STDOUT->autoflush(0);
+      return '<';
+   }
+   my $c="aws ses verify-email-identity --email-address $domain";
+   my ($hash,$output,$error)=&Net::FullAuto::Cloud::fa_amazon::run_aws_cmd($c);
+   my $inform_banner=<<'END';
+
+    ___                     _            _   _
+   |_ _|_ __  _ __  ___ _ _| |_ __ _ _ _| |_| |
+    | || '  \| '_ \/ _ \ '_|  _/ _` | ' \  _|_|
+   |___|_|_|_| .__/\___/_|  \__\__,_|_||_\__(_)
+             |_|
+
+END
+   $inform_banner.=<<END;
+   The domain name you just entered: $domain
+
+   has been submitted to Amazon Web Services for verification. Amazon
+   will be sending an email to this address that you must respond to
+   in order for this address to work with your GNU Social installation.
+   You can take a few minutes to do this now, or after you complete this
+   installation. Just note, that email in your GNU Social server will
+   not work until you have responded to Amazon's email.
+
+END
+   my $email_message={
+
+      Name => 'email_message',
+      Result => $gnusocial_setup_summary,
+      Banner => $inform_banner,
+
+   };
+   return $email_message;
+
+};
+
+our $gnusocial_enter_domain_name=sub {
+
+   my $gnusocial_domain_banner=<<'END';
+
+    ___     _             ___                 _        _  _
+   | __|_ _| |_ ___ _ _  |   \ ___ _ __  __ _(_)_ _   | \| |__ _ _ __  ___
+   | _|| ' \  _/ -_) '_| | |) / _ \ '  \/ _` | | ' \  | .` / _` | '  \/ -_)
+   |___|_||_\__\___|_|   |___/\___/_|_|_\__,_|_|_||_| |_|\_\__,_|_|_|_\___|
+
+   The Domain Name is the friendly address of your site - like fullauto.com
+   This setup will test the validity of your domain name, and coach you
+   through the steps you need to take to activate it successfully.
+
+END
+   $gnusocial_domain_banner.=<<END;
+
+   Input box with === border is highlighted (active) input box.
+   Use [TAB] key to switch focus between input boxes.
+   Use [DEL] key to clear entire entry in highlighted input box.
+   Use [Backspace] to backspace in highlighted input box.
+
+   Type or Copy & Paste the Domain Name for GNU Social here:
+
+
+   Domain Name
+                    ]I[{1,'',50}
+
+END
+
+   my $gnusocial_enter_domain_name={
+
+      Name => 'gnusocial_enter_domain_name',
+      Input => 1,
+      Result => $gnusocial_validate_domain,
+      #Result => $gnusocial_setup_summary,
+      Banner => $gnusocial_domain_banner,
+
+   };
+   return $gnusocial_enter_domain_name;
+
+};
+
 our $select_gnusocial_setup=sub {
 
    my @options=('GNU Social & MySQL & NGINX on 1 Server');
@@ -1418,6 +1572,7 @@ END
          Text => ']C[',
          Convey => \@options,
          Result => $gnusocial_pick_email_address,
+         #Result => $gnusocial_enter_domain_name,
 
       },
       Scroll => 1,
